# Raumplaner.py

from grafikfenster import *

from schrank import Schrank
from stuhl import Stuhl
from tisch import Tisch
from sessel import Sessel
from sofa import Sofa

import pickle

### ---------------------------------------------------
class RaumplanerApp(wx.App):
    """Testanwendung fuer Raumplaner-Grafik
       ShellFrame: Interaktion mit laufender Anwendung
       FillingFrame: Anzeige der Umgebung"""
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        #self.fenster.ZeigeFillingFrame()
        self.__alleMoebel=[] # zum Sichern / Laden
        self.TestAnwendung()
        return True

    def TestAnwendung(self):
        # Allein fuer die Testanwendung:
        #global stuhl,tisch,schrank,sessel,sofa
        stuhl=Stuhl(30, 30, 40, 40, 270, 'blue', True)
        tisch=Tisch(80, 20, 120, 60, 0, 'red', True)
        schrank=Schrank(300,80,60,37,90,'brown',True)
        sessel=Sessel(130, 120, 60, 60, 0, 'orange', True)
        sofa=Sofa(10, 220, 140, 60, 270, 'orange', True)
        self.__alleMoebel=[stuhl,tisch,schrank,sessel,sofa]
    
    def AlleLoeschen(self):
        for moebel in self.__alleMoebel:
            moebel.Verberge()
        self.__alleMoebel=[]

    def BildExport(self, dateiname="Bild.png"):
        Zeichenflaeche.GibZeichenflaeche().BildExport(dateiname)

### ------ Umsetzen des Speicherns / Ladens ----------------
    def Speichere(self, dateiname):
        """Objektdaten werden in Datei geschrieben"""
        try:
            with open(dateiname, 'wb') as objekt_datei:
                print(self.__alleMoebel)
                pickle.dump(self.__alleMoebel, objekt_datei)
            return 'OK'
        except IOError as ioerr:
            return 'Dateifehler: ' + str(ioerr)
        except pickle.PicklingError as perr:
            return 'Pickle­Fehler: ' + str(perr)

    def Lade(self, dateiname):
        """Objektdaten werden aus der Datei gelesen"""
        self.AlleLoeschen()
        try:
            with open(dateiname, 'rb') as objekt_datei:
                self.__alleMoebel = pickle.load(objekt_datei)
            for moebel in self.__alleMoebel:
                moebel.Update()
            return 'OK'
        except IOError:
            return 'Datei nicht auffindbar!'
        except AttributeError as ae:
            return 'AttributeError: ' + str(ae)
        except pickle.UnpicklingError as perr:
            return 'Pickle­Fehler: ' + str(perr)
        
### ---------------------------------------------------
if __name__ == '__main__':
    app = RaumplanerApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
